@@ -47,23 +47,24 @@ import org.opennms.features.topology.api.topo.AbstractEdge;
 import org.opennms.features.topology.api.topo.DefaultVertexRef;
 import org.opennms.features.topology.api.topo.GraphProvider;
 import org.opennms.features.topology.api.topo.Vertex;
-import org.opennms.netmgt.dao.api.BridgeBridgeLinkDao;
-import org.opennms.netmgt.dao.api.BridgeMacLinkDao;
+import org.opennms.features.topology.plugins.topo.linkd.internal.LinkdTopologyProvider.ProtocolSupported;
 import org.opennms.netmgt.dao.api.BridgeTopologyDao;
 import org.opennms.netmgt.dao.api.CdpElementDao;
 import org.opennms.netmgt.dao.api.CdpLinkDao;
 import org.opennms.netmgt.dao.api.IpInterfaceDao;
 import org.opennms.netmgt.dao.api.IpNetToMediaDao;
+import org.opennms.netmgt.dao.api.IsIsElementDao;
 import org.opennms.netmgt.dao.api.IsIsLinkDao;
 import org.opennms.netmgt.dao.api.LldpElementDao;
 import org.opennms.netmgt.dao.api.LldpLinkDao;
 import org.opennms.netmgt.dao.api.NodeDao;
 import org.opennms.netmgt.dao.api.OspfLinkDao;
 import org.opennms.netmgt.dao.api.SnmpInterfaceDao;
-import org.opennms.netmgt.model.BridgeBridgeLink;
 import org.opennms.netmgt.model.CdpElement;
 import org.opennms.netmgt.model.CdpLink;
 import org.opennms.netmgt.model.IpNetToMedia;
+import org.opennms.netmgt.model.IsIsElement;
+import org.opennms.netmgt.model.IsIsLink;
 import org.opennms.netmgt.model.LldpElement;
 import org.opennms.netmgt.model.LldpLink;
 import org.opennms.netmgt.model.NetworkBuilder;
@@ -71,9 +72,7 @@ import org.opennms.netmgt.model.OnmsIpInterface;
 import org.opennms.netmgt.model.OnmsNode;
 import org.opennms.netmgt.model.OnmsSnmpInterface;
 import org.opennms.netmgt.model.OspfLink;
-import org.opennms.netmgt.model.topology.BridgeMacTopologyLink;
 import org.opennms.netmgt.model.topology.BroadcastDomain;
-import org.opennms.netmgt.model.topology.IsisTopologyLink;
 import org.springframework.beans.factory.annotation.Autowired;
 
 public class EnhancedLinkdMockDataPopulator {
@@ -81,12 +80,6 @@ public class EnhancedLinkdMockDataPopulator {
     @Autowired
     private BridgeTopologyDao m_bridgeTopologyDao;
 
-    @Autowired
-    private BridgeBridgeLinkDao m_bridgeBridgeLinkDao;
-
-    @Autowired
-    private BridgeMacLinkDao m_bridgeMacLinkDao;
-
     @Autowired
     private CdpLinkDao m_cdpLinkDao;
 
@@ -96,6 +89,9 @@ public class EnhancedLinkdMockDataPopulator {
     @Autowired
     private IsIsLinkDao m_isisLinkDao;
 
+    @Autowired
+    private IsIsElementDao m_isisElementDao;
+
     @Autowired
     private LldpLinkDao m_lldpLinkDao;
 
@@ -410,13 +406,11 @@ public class EnhancedLinkdMockDataPopulator {
     }
 
     public void setUpMock() {
-        EasyMock.expect(m_bridgeBridgeLinkDao.findAll()).andReturn(new ArrayList<BridgeBridgeLink>()).anyTimes();
-        EasyMock.expect(m_bridgeMacLinkDao.getAllBridgeLinksToBridgeNodes()).andReturn(new ArrayList<BridgeMacTopologyLink>()).anyTimes();
-        EasyMock.expect(m_bridgeMacLinkDao.getAllBridgeLinksToIpAddrToNodes()).andReturn(new ArrayList<BridgeMacTopologyLink>()).anyTimes();
         EasyMock.expect(m_cdpLinkDao.findAll()).andReturn(new ArrayList<CdpLink>()).anyTimes();
         EasyMock.expect(m_cdpElementDao.findAll()).andReturn(new ArrayList<CdpElement>()).anyTimes();
         EasyMock.expect(m_bridgeTopologyDao.load()).andReturn(new HashSet<BroadcastDomain>()).anyTimes();
-        EasyMock.expect(m_isisLinkDao.getLinksForTopology()).andReturn(new ArrayList<IsisTopologyLink>()).anyTimes();
+        EasyMock.expect(m_isisLinkDao.findAll()).andReturn(new ArrayList<IsIsLink>()).anyTimes();
+        EasyMock.expect(m_isisElementDao.findAll()).andReturn(new ArrayList<IsIsElement>()).anyTimes();
 
         EasyMock.expect(m_nodeDao.findAll()).andReturn(getNodes()).anyTimes();
         EasyMock.expect(m_ipInterfaceDao.findAll()).andReturn(getOnmsIpInterfaces()).anyTimes();
@@ -435,10 +429,11 @@ public class EnhancedLinkdMockDataPopulator {
             EasyMock.expect(m_ipInterfaceDao.findByNodeId(i)).andReturn(getList(getNode(i).getIpInterfaces())).anyTimes();
         }
         
-        EasyMock.replay(m_bridgeBridgeLinkDao, m_bridgeMacLinkDao, m_cdpLinkDao, m_isisLinkDao,m_bridgeTopologyDao);
+        EasyMock.replay(m_cdpLinkDao, m_isisLinkDao,m_bridgeTopologyDao);
         EasyMock.replay(m_cdpElementDao);
         EasyMock.replay(m_lldpLinkDao);
         EasyMock.replay(m_lldpElementDao);
+        EasyMock.replay(m_isisElementDao);
         EasyMock.replay(m_ospfLinkDao);
         EasyMock.replay(m_nodeDao);
         EasyMock.replay(m_snmpInterfaceDao);
@@ -447,9 +442,10 @@ public class EnhancedLinkdMockDataPopulator {
     }
 
     public void tearDown() {
-        EasyMock.reset(m_bridgeBridgeLinkDao, m_bridgeMacLinkDao, m_cdpLinkDao, m_isisLinkDao,m_bridgeTopologyDao);
+        EasyMock.reset(m_cdpLinkDao, m_isisLinkDao,m_bridgeTopologyDao);
         EasyMock.reset(m_cdpElementDao);
         EasyMock.reset(m_lldpElementDao);
+        EasyMock.reset(m_isisElementDao);
         EasyMock.reset(m_lldpLinkDao);
         EasyMock.reset(m_ospfLinkDao);
         EasyMock.reset(m_nodeDao);
@@ -622,38 +618,38 @@ public class EnhancedLinkdMockDataPopulator {
         EasyMock.expect(mockVertex.getLabel()).andReturn(null).anyTimes();
         EasyMock.replay(mockVertex);
         AbstractEdge[] edgeidsforvertex1 = {
-                new AbstractEdge(EnhancedLinkdTopologyProvider.LLDP_EDGE_NAMESPACE, "10018|10081", mockVertex, mockVertex),
-                new AbstractEdge(EnhancedLinkdTopologyProvider.LLDP_EDGE_NAMESPACE, "10012|10021", mockVertex, mockVertex),
-                new AbstractEdge(EnhancedLinkdTopologyProvider.OSPF_EDGE_NAMESPACE, "10112|10121", mockVertex, mockVertex)
+                LinkdEdge.create("10018|10081", mockVertex, mockVertex,ProtocolSupported.LLDP),
+                LinkdEdge.create("10012|10021", mockVertex, mockVertex,ProtocolSupported.LLDP),
+                LinkdEdge.create("10112|10121", mockVertex, mockVertex,ProtocolSupported.OSPF)
         };
         AbstractEdge[] edgeidsforvertex2 = {
-                new AbstractEdge(EnhancedLinkdTopologyProvider.LLDP_EDGE_NAMESPACE, "10023|10032", mockVertex, mockVertex),
-                new AbstractEdge(EnhancedLinkdTopologyProvider.LLDP_EDGE_NAMESPACE, "10012|10021", mockVertex, mockVertex),
-                new AbstractEdge(EnhancedLinkdTopologyProvider.OSPF_EDGE_NAMESPACE, "10112|10121", mockVertex, mockVertex)
+                LinkdEdge.create("10023|10032", mockVertex, mockVertex,ProtocolSupported.LLDP),
+                LinkdEdge.create("10012|10021", mockVertex, mockVertex,ProtocolSupported.LLDP),
+                LinkdEdge.create("10112|10121", mockVertex, mockVertex,ProtocolSupported.OSPF)
         };
         AbstractEdge[] edgeidsforvertex3 = {
-                new AbstractEdge(EnhancedLinkdTopologyProvider.LLDP_EDGE_NAMESPACE, "10023|10032", mockVertex, mockVertex),
-                new AbstractEdge(EnhancedLinkdTopologyProvider.LLDP_EDGE_NAMESPACE, "10034|10043", mockVertex, mockVertex)
+                LinkdEdge.create("10023|10032", mockVertex, mockVertex,ProtocolSupported.LLDP),
+                LinkdEdge.create("10034|10043", mockVertex, mockVertex,ProtocolSupported.LLDP)
         };
         AbstractEdge[] edgeidsforvertex4 = {
-                new AbstractEdge(EnhancedLinkdTopologyProvider.LLDP_EDGE_NAMESPACE, "10045|10054", mockVertex, mockVertex),
-                new AbstractEdge(EnhancedLinkdTopologyProvider.LLDP_EDGE_NAMESPACE, "10034|10043", mockVertex, mockVertex)
+                LinkdEdge.create("10045|10054", mockVertex, mockVertex,ProtocolSupported.LLDP),
+                LinkdEdge.create("10034|10043", mockVertex, mockVertex,ProtocolSupported.LLDP)
         };
         AbstractEdge[] edgeidsforvertex5 = {
-                new AbstractEdge(EnhancedLinkdTopologyProvider.LLDP_EDGE_NAMESPACE, "10045|10054", mockVertex, mockVertex),
-                new AbstractEdge(EnhancedLinkdTopologyProvider.LLDP_EDGE_NAMESPACE, "10056|10065", mockVertex, mockVertex)
+                LinkdEdge.create("10045|10054", mockVertex, mockVertex,ProtocolSupported.LLDP),
+                LinkdEdge.create("10056|10065", mockVertex, mockVertex,ProtocolSupported.LLDP)
         };
         AbstractEdge[] edgeidsforvertex6 = {
-                new AbstractEdge(EnhancedLinkdTopologyProvider.LLDP_EDGE_NAMESPACE, "10056|10065", mockVertex, mockVertex),
-                new AbstractEdge(EnhancedLinkdTopologyProvider.LLDP_EDGE_NAMESPACE, "10067|10076", mockVertex, mockVertex)
+                LinkdEdge.create("10056|10065", mockVertex, mockVertex,ProtocolSupported.LLDP),
+                LinkdEdge.create("10067|10076", mockVertex, mockVertex,ProtocolSupported.LLDP)
         };
         AbstractEdge[] edgeidsforvertex7 = {
-                new AbstractEdge(EnhancedLinkdTopologyProvider.LLDP_EDGE_NAMESPACE, "10078|10087", mockVertex, mockVertex),
-                new AbstractEdge(EnhancedLinkdTopologyProvider.LLDP_EDGE_NAMESPACE, "10067|10076", mockVertex, mockVertex)
+                LinkdEdge.create("10078|10087", mockVertex, mockVertex,ProtocolSupported.LLDP),
+                LinkdEdge.create("10067|10076", mockVertex, mockVertex,ProtocolSupported.LLDP)
         };
         AbstractEdge[] edgeidsforvertex8 = {
-                new AbstractEdge(EnhancedLinkdTopologyProvider.LLDP_EDGE_NAMESPACE, "10018|10081", mockVertex, mockVertex),
-                new AbstractEdge(EnhancedLinkdTopologyProvider.LLDP_EDGE_NAMESPACE, "10078|10087", mockVertex, mockVertex)
+                LinkdEdge.create("10018|10081", mockVertex, mockVertex,ProtocolSupported.LLDP),
+                LinkdEdge.create("10078|10087", mockVertex, mockVertex,ProtocolSupported.LLDP)
         };
         OnmsAssert.assertArrayEqualsIgnoreOrder(topologyProvider.getEdgeIdsForVertex(new DefaultVertexRef(vertexNamespace, "1")), edgeidsforvertex1);
         OnmsAssert.assertArrayEqualsIgnoreOrder(topologyProvider.getEdgeIdsForVertex(new DefaultVertexRef(vertexNamespace, "2")), edgeidsforvertex2);
