@@ -28,9 +28,6 @@
 
 package org.opennms.features.vaadin.dashboard.dashlets;
 
-import java.io.UnsupportedEncodingException;
-import java.net.URLDecoder;
-import java.nio.charset.StandardCharsets;
 import java.util.Calendar;
 import java.util.List;
 import java.util.Map;
