@@ -42,11 +42,8 @@ import java.io.IOException;
 import java.net.ConnectException;
 import java.net.InetAddress;
 import java.net.MalformedURLException;
-import java.net.URL;
 import java.rmi.RemoteException;
 import java.security.SecureRandom;
-import java.security.cert.CertificateException;
-import java.security.cert.X509Certificate;
 import java.util.ArrayList;
 import java.util.Enumeration;
 import java.util.HashMap;
@@ -60,8 +57,6 @@ import javax.net.ssl.HttpsURLConnection;
 import javax.net.ssl.SSLContext;
 import javax.net.ssl.SSLSession;
 import javax.net.ssl.TrustManager;
-import javax.net.ssl.X509TrustManager;
-
 import org.opennms.core.spring.BeanUtils;
 import org.opennms.core.utils.AnyServerX509TrustManager;
 import org.opennms.netmgt.collectd.vmware.vijava.VmwarePerformanceValues;
@@ -135,6 +130,8 @@ public class VmwareViJavaAccess {
 
     private Map<HostSystem, String> m_hostSystemCimUrls = new HashMap<HostSystem, String>();
 
+    private static ServiceInstancePool m_serviceInstancePool = new ServiceInstancePool();
+
     /**
      * Constructor for creating a instance for a given server and credentials.
      *
@@ -206,7 +203,7 @@ public class VmwareViJavaAccess {
     public void connect() throws MalformedURLException, RemoteException {
         relax();
 
-        m_serviceInstance = new ServiceInstance(new URL("https://" + m_hostname + "/sdk"), m_username, m_password);
+        m_serviceInstance = m_serviceInstancePool.retain(m_hostname, m_username, m_password);
     }
 
     /**
@@ -237,19 +234,7 @@ public class VmwareViJavaAccess {
      * Disconnects from the server.
      */
     public void disconnect() {
-        if (m_serviceInstance == null) {
-            // not connected
-            return;
-        } else {
-            ServerConnection serverConnection = m_serviceInstance.getServerConnection();
-
-            if (serverConnection == null) {
-                // not connected
-                return;
-            } else {
-                m_serviceInstance.getServerConnection().logout();
-            }
-        }
+        m_serviceInstancePool.release(m_serviceInstance);
     }
 
     /**
