@@ -29,10 +29,13 @@ package org.opennms.smoketest;
 import static org.junit.Assert.assertEquals;
 import org.junit.Before;
 import org.junit.FixMethodOrder;
+import org.junit.Ignore;
 import org.junit.Test;
 import org.junit.runners.MethodSorters;
 import org.openqa.selenium.By;
 import org.openqa.selenium.support.ui.Select;
+
+@Ignore("Flapping. See NMS-10129.")
 @FixMethodOrder(MethodSorters.NAME_ASCENDING)
 public class ThresholdEditorIT extends OpenNMSSeleniumTestCase {
     @Before
@@ -267,4 +270,4 @@ public class ThresholdEditorIT extends OpenNMSSeleniumTestCase {
         waitForElement(By.xpath("//h3[text()='Basic Thresholds']"));
         assertEquals(1, countElementsMatchingCss(".edit-group-expression-based-thresholds tr"));
     }
-}
\ No newline at end of file
+}
